==> finetuner-0.6.2.tar.gz: finetuner-0.6.2/finetuner/constants.py <==
DELETE = 'DELETE'
POST = 'POST'
GET = 'GET'
NAME = 'name'
HUBBLE_USER_ID = '_id'
ID = 'id'

HOST = 'JINA_FINETUNER_REGISTRY'
HUBBLE_REGISTRY = 'JINA_HUBBLE_REGISTRY'
DEFAULT_FINETUNER_HOST = 'https://api.finetuner.fit'
DEFAULT_HUBBLE_REGISTRY = 'https://api.hubble.jina.ai'

CONFIG = 'config'
FINETUNER_VERSION = 'finetuner_version'
DEVICE = 'device'
CPU = 'cpu'
CPUS = 'cpus'
GPUS = 'gpus'
NUM_WORKERS = 'num_workers'
RUNS = 'runs'
STATUS = 'status'
LOGS = 'logs'
LOGSTREAM = 'logstream'
EXPERIMENTS = 'experiments'
API_VERSION = 'api/v1'
AUTHORIZATION = 'Authorization'
CHARSET = 'Accept-Charset'
UTF_8 = 'utf-8'
TEXT = 'text'
TOKEN_PREFIX = 'token '
DATA = 'data'
TRAIN_DATA = 'train_data'
EVAL_DATA = 'eval_data'
ARTIFACTS_DIR = 'artifacts/'
MODEL = 'model'
MODEL_OPTIONS = 'model_options'
ARTIFACT_ID = 'artifact_id'
# Run status
CREATED = 'CREATED'
STARTED = 'STARTED'
FINISHED = 'FINISHED'
FAILED = 'FAILED'
DEFAULT_EXPERIMENT_NAME = 'default_experiment'
CREATED_AT = 'created_at'
DESCRIPTION = 'description'
FREEZE = 'freeze'
OUTPUT_DIM = 'output_dim'
MULTI_MODAL = 'multi_modal'
IMAGE_MODALITY = 'image_modality'
TEXT_MODALITY = 'text_modality'
HYPER_PARAMETERS = 'hyper_parameters'
LOSS = 'loss'
OPTIMIZER = 'optimizer'
MINER = 'miner'
MINER_OPTIONS = 'miner_options'
BATCH_SIZE = 'batch_size'
LEARNING_RATE = 'learning_rate'
EPOCHS = 'epochs'
EXPERIMENT_NAME = 'experiment_name'
RUN_NAME = 'run_name'
OPTIMIZER_OPTIONS = 'optimizer_options'
SCHEDULER_STEP = 'scheduler_step'
CALLBACKS = 'callbacks'
OPTIONS = 'options'
QUERY_DATA = 'query_data'
INDEX_DATA = 'index_data'
DA_PREFIX = 'finetuner-dastorage'
ONNX = 'to_onnx'

==> finetuner-0.7.0.tar.gz: finetuner-0.7.0/finetuner/constants.py <==
DELETE = 'DELETE'
POST = 'POST'
GET = 'GET'
NAME = 'name'
HUBBLE_USER_ID = '_id'
ID = 'id'

HOST = 'JINA_FINETUNER_REGISTRY'
HUBBLE_REGISTRY = 'JINA_HUBBLE_REGISTRY'
DEFAULT_FINETUNER_HOST = 'https://api.finetuner.fit'
DEFAULT_HUBBLE_REGISTRY = 'https://api.hubble.jina.ai'

CONFIG = 'config'
FINETUNER_VERSION = 'finetuner_version'
DEVICE = 'device'
CPUS = 'cpus'
GPUS = 'gpus'
NUM_WORKERS = 'num_workers'
RUNS = 'runs'
STATUS = 'status'
LOGS = 'logs'
LOGSTREAM = 'logstream'
EXPERIMENTS = 'experiments'
API_VERSION = 'api/v1'
AUTHORIZATION = 'Authorization'
CHARSET = 'Accept-Charset'
UTF_8 = 'utf-8'
TEXT = 'text'
TOKEN_PREFIX = 'token '
DATA = 'data'
TRAIN_DATA = 'train_data'
EVAL_DATA = 'eval_data'
VAL_SPLIT = 'val_split'
ARTIFACTS_DIR = 'artifacts/'
MODEL = 'model'
MODEL_OPTIONS = 'model_options'
ARTIFACT_ID = 'artifact_id'
DEFAULT_TAG_KEY = 'finetuner_label'
# Run status
CREATED = 'CREATED'
STARTED = 'STARTED'
FINISHED = 'FINISHED'
FAILED = 'FAILED'
DEFAULT_EXPERIMENT_NAME = 'default_experiment'
CREATED_AT = 'created_at'
DESCRIPTION = 'description'
FREEZE = 'freeze'
OUTPUT_DIM = 'output_dim'
MULTI_MODAL = 'multi_modal'
IMAGE_MODALITY = 'image_modality'
TEXT_MODALITY = 'text_modality'
HYPER_PARAMETERS = 'hyper_parameters'
LOSS = 'loss'
LOSS_OPTIONS = 'loss_options'
OPTIMIZER = 'optimizer'
MINER = 'miner'
MINER_OPTIONS = 'miner_options'
BATCH_SIZE = 'batch_size'
LEARNING_RATE = 'learning_rate'
EPOCHS = 'epochs'
EXPERIMENT_NAME = 'experiment_name'
RUN_NAME = 'run_name'
OPTIMIZER_OPTIONS = 'optimizer_options'
SCHEDULER_STEP = 'scheduler_step'
CALLBACKS = 'callbacks'
OPTIONS = 'options'
QUERY_DATA = 'query_data'
INDEX_DATA = 'index_data'
DA_PREFIX = 'finetuner-dastorage'
ONNX = 'to_onnx'
PUBLIC = 'public'
NUM_ITEMS_PER_CLASS = 'num_items_per_class'
VAL_SPLIT = 'val_split'
